gd_band_names: Get Names of Layers in an Earth Engine Image

View source: R/search.R

gd_band_namesR Documentation

Get Names of Layers in an Earth Engine Image

Description

Calls bandNames() method from ee.Image class.

Usage

gd_band_names(x)

Arguments

x

a geedim.image.ImageAccessor (for geedim >= 2.0.0) or geedim.download.BaseImage (for geedim < 2.0.0) object, such as from gd_image_from_id(). See ⁠\link{geedim-versions}⁠ for more details.

Value

character. Vector of names of each layer in an image.

Examples



if (gd_is_initialized())
  gd_band_names(gd_image_from_id("USGS/SRTMGL1_003"))



rgeedim documentation built on Feb. 2, 2026, 9:06 a.m.