Learn R Programming

rgeedim (version 0.4.0)

gd_band_names: Get Names of Layers in an Earth Engine Image

Description

Calls bandNames() method from ee.Image class.

Usage

gd_band_names(x)

Value

character. Vector of names of each layer in an image.

Arguments

x

a geedim.image.ImageAccessor (for geedim >= 2.0.0) or geedim.download.BaseImage (for geedim < 2.0.0) object, such as from gd_image_from_id(). See \link{geedim-versions} for more details.

Examples

Run this code
if (FALSE) { # isTRUE(as.logical(Sys.getenv("R_RGEEDIM_RUN_EXAMPLES"))) && gd_is_initialized()
# \donttest{
if (gd_is_initialized())
  gd_band_names(gd_image_from_id("USGS/SRTMGL1_003"))
# }
}

Run the code above in your browser using DataLab