gd_band_properties: Get Properties of Layers in an Earth Engine Image
Description
Gets combined Earth Engine and STAC properties.
Usage
gd_band_properties(x)
Value
list. Each element is a list that corresponds to a layer in x, each with one or more elements for properties of that layer.
Arguments
x
a geedim.image.ImageAccessor (for geedim >= 2.0.0) or geedim.download.BaseImage (for geedim < 2.0.0) object, such as from gd_image_from_id(). See \link{geedim-versions} for more details.