gd_bbox: Prepare Bounding Box Region from X/Y Limits
Description
Create a bounding box polygon Python object for use with gd_download(). The coordinates of the bounding box are expressed in WGS84 decimal degrees ("OGC:CRS84").
Usage
gd_bbox(...)
Value
a list object describing a GeoJSON bounding rectangular polygon suitable for use as regions argument to gd_download() or gd_search()
Arguments
...
One or more SpatRaster, SpatRasterCollection, SpatVector, SpatVectorProxy or SpatExtent objects (whose combined bounding box extent will be returned); or the following named numeric arguments: xmin/ymax/xmax/ymin. If these four limit arguments are not named they should be in the stated order.
Details
Expecting total of 4 bounding box arguments, If arguments are unnamed they should be in the following order: "xmin", "ymax", "xmax", "ymin".