| gd_initialize | R Documentation |
geedimCalls geedim Initialize() method. This method should be called at the beginning of each session.
gd_initialize(
private_key_file = NULL,
credentials = NULL,
cloud_api_key = NULL,
url = "https://earthengine-highvolume.googleapis.com",
http_transport = NULL,
project = NULL,
quiet = FALSE
)
gd_is_initialized(..., quiet = TRUE)
private_key_file |
character. Optional: Path to JSON file containing service account credentials. (Deprecated in v0.3.0: use |
credentials |
Default: |
cloud_api_key |
An optional API key to use the Cloud API. Default: |
url |
The base url for the EarthEngine REST API to connect to. Defaults to "High Volume" endpoint: |
http_transport |
The HTTP transport method to use when making requests. Default: |
project |
The client project ID or number to use when making API calls. Default: |
quiet |
Suppress error messages? Default: |
... |
Additional arguments passed to |
Authentication is handled automatically by Google Application Default Credentials (ADC). When credentials is NULL (the default), the underlying Python libraries will automatically search for credentials in the following order:
GOOGLE_APPLICATION_CREDENTIALS environment variable (if set)
User credentials from gcloud auth application-default login
Attached service account (when running on Google Cloud infrastructure)
In a headless environment (e.g. CI/CD), use GOOGLE_APPLICATION_CREDENTIALS to specify the service account key file path and GOOGLE_CLOUD_QUOTA_PROJECT to specify the project ID responsible for quota and billing.
The deprecated private_key_file parameter is provided for backward compatibility. If specified and GOOGLE_APPLICATION_CREDENTIALS is not already set, the file path will be used to set that environment variable for the Python libraries to discover.
gd_initialize(): try-error (invisibly) on error.
gd_is_initialized(): logical. TRUE if initialized successfully.
gd_authenticate()
## Not run:
gd_initialize()
## End(Not run)
gd_is_initialized()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.